package com.ruoyi.framework.recovery.mapper;

import java.util.List;
import com.ruoyi.framework.recovery.domain.RecCommodity;

/**
 * 回收品牌Mapper接口
 * 
 * @author jin
 * @date 2024-11-16
 */
public interface RecCommodityMapper 
{
    /**
     * 查询回收品牌
     * 
     * @param id 回收品牌主键
     * @return 回收品牌
     */
    public RecCommodity selectRecCommodityById(Long id);

    /**
     * 查询回收品牌列表
     * 
     * @param recCommodity 回收品牌
     * @return 回收品牌集合
     */
    public List<RecCommodity> selectRecCommodityList(RecCommodity recCommodity);

    /**
     * 新增回收品牌
     * 
     * @param recCommodity 回收品牌
     * @return 结果
     */
    public int insertRecCommodity(RecCommodity recCommodity);

    /**
     * 修改回收品牌
     * 
     * @param recCommodity 回收品牌
     * @return 结果
     */
    public int updateRecCommodity(RecCommodity recCommodity);

    /**
     * 删除回收品牌
     * 
     * @param id 回收品牌主键
     * @return 结果
     */
    public int deleteRecCommodityById(Long id);

    /**
     * 批量删除回收品牌
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRecCommodityByIds(Long[] ids);
}
